@@ -1,4 +1,3 @@
-/* $Id: weather-http.c 7747 2009-07-19 20:55:22Z colin $ */
 /*
  * Copyright (c) 2007 Nick Schermer <nick@xfce.org>
  *
@@ -21,6 +20,8 @@
 #include <config.h>
 #endif
 
+#include <sys/select.h>
+#include <sys/time.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <sys/stat.h>
@@ -38,7 +39,7 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <libxfce4util/libxfce4util.h>
-#include <libxfce4panel/xfce-panel-macros.h>
+#include <libxfce4panel/libxfce4panel.h>
 
 #include "weather-http.h"
 
@@ -85,7 +86,8 @@ struct _WeatherConnection
   gint         status;
 
   /* received data */
-  GString     *received;
+  gchar     *received;
+  size_t    received_len;
 
   /* connection descriptor */
   gint         fd;
@@ -132,7 +134,7 @@ static void refresh_resolvers(void)
 #ifdef G_OS_UNIX
 static sigjmp_buf jmpenv;
 
-static void timeout_handler(gint sig)
+G_GNUC_NORETURN static void timeout_handler(gint sig)
 {
 	siglongjmp(jmpenv, 1);
 }
@@ -145,9 +147,10 @@ weather_http_receive_data_idle (gpointer user_data)
   gchar               buffer[1024];
   gint                bytes, n, m;
   gchar              *request;
-  
+  fd_set              fds;
+  struct timeval      select_timeout;
   struct addrinfo     h, *r, *a;
-  const gchar         *port = NULL;
+  gchar      	     *port = NULL;
   gint                err;
 
   const gchar        *p;
@@ -176,15 +179,15 @@ weather_http_receive_data_idle (gpointer user_data)
 #endif
 
   memset(&h, 0, sizeof(h));
-  h.ai_family = AF_INET;
+  h.ai_family = AF_UNSPEC;
   h.ai_socktype = SOCK_STREAM;
   h.ai_protocol = IPPROTO_TCP;
-  
+
   if (connection->proxy_port)
   	port = g_strdup_printf("%d", connection->proxy_port);
   else
   	port = g_strdup("80");
-  
+
   err = getaddrinfo(connection->proxy_host ? connection->proxy_host : connection->hostname,
   		port, &h, &r);
 
@@ -210,7 +213,7 @@ weather_http_receive_data_idle (gpointer user_data)
     return FALSE;
 
   /* open the socket */
-  
+
   for (a = r; a != NULL; a = a->ai_next) {
     connection->fd = socket (a->ai_family, a->ai_socktype, a->ai_protocol);
     if (connection->fd < 0) {
@@ -228,7 +231,7 @@ weather_http_receive_data_idle (gpointer user_data)
 #endif
     if (m == 0)
       break;
-    else 
+    else
       err = errno;
 
     if (weather_http_receive_data_check (connection, timeout))
@@ -267,7 +270,7 @@ weather_http_receive_data_idle (gpointer user_data)
     request = g_strdup_printf ("GET %s HTTP/1.1\r\n"
     				"Host: %s\r\n"
 				"Connection: close\r\n"
-				"\r\n", 
+				"\r\n",
 				connection->url, connection->hostname);
 
   /* send the request */
@@ -277,7 +280,11 @@ weather_http_receive_data_idle (gpointer user_data)
       bytes = send (connection->fd, request + m, n - m, 0);
 
       if (weather_http_receive_data_check (connection, timeout))
-        return FALSE;
+        {
+          g_free (request);
+
+          return FALSE;
+        }
 
       /* check for problems */
       if (G_UNLIKELY (bytes < 0))
@@ -308,19 +315,35 @@ weather_http_receive_data_idle (gpointer user_data)
   g_free (request);
 
   /* create and empty string */
-  connection->received = g_string_sized_new (5000);
+  connection->received_len = 0;
 
   /* download the file content */
+  FD_ZERO (&fds);
   do
     {
-      /* download some bytes */
-      bytes = recv (connection->fd, buffer, sizeof (buffer) - sizeof (gchar), 0);
+      /* FIXME: recv() may block. send() and connect() may block too and the
+       * only right solution is to rewrite whole code using non-blocking
+       * sockets, but that's hard, connect() is already protected with alarm()
+       * and send() blocks only when socket buffers are ultra-small */
+      FD_SET (connection->fd, &fds);
+      select_timeout.tv_sec = WEATHER_MAX_CONN_TIMEOUT;
+      select_timeout.tv_usec = 0;
 
-      if (weather_http_receive_data_check (connection, timeout))
-        return FALSE;
+      m = select (connection->fd+1, &fds, 0, 0, &select_timeout);
+      if (G_LIKELY (m == 1))
+        {
+          bytes = recv (connection->fd, buffer, sizeof (buffer) - sizeof (gchar), 0);
+          if (G_LIKELY (bytes > 0))
+            {
+              /* prepend the downloaded data */
+              connection->received = g_realloc(connection->received, connection->received_len + bytes);
+              memcpy(connection->received+connection->received_len, buffer, bytes);
+              connection->received_len += bytes;
+            }
+        }
 
       /* check for problems */
-      if (G_UNLIKELY (bytes < 0))
+      if (G_UNLIKELY (m < 0 || bytes < 0))
         {
           /* display warning */
           g_warning (_("Failed to receive data (%s)"), g_strerror (errno));
@@ -331,31 +354,52 @@ weather_http_receive_data_idle (gpointer user_data)
           return FALSE;
         }
 
-      /* prepend the downloaded data */
-      connection->received = g_string_append_len (connection->received, buffer, bytes);
+      if (weather_http_receive_data_check (connection, timeout))
+        return FALSE;
     }
   while (bytes > 0);
 
-  if (weather_http_receive_data_check (connection, timeout))
-    return FALSE;
-
-  if (G_LIKELY (connection->received->len > 0))
+  if (G_LIKELY (connection->received_len > 0))
     {
       /* get the pointer to the content-length */
-      p = strstr (connection->received->str, "Content-Length:");
-
+      int cts_len = -1;
+      p = strstr ((char *)connection->received, "Content-Length:");
       if (G_LIKELY (p))
         {
           /* advance the pointer */
-          p += 15;
+          p += strlen("Content-Length:");
 
+          cts_len = strtol (p, NULL, 10);
+          if (G_UNLIKELY (cts_len < 0))
+            {
+              g_warning(_("Negative content length"));
+
+              /* set status */
+              connection->status = STATUS_ERROR;
+            }
+        }
+      else
+        {
+          /* hack for archive.xfce.org, which return no content-length */
+          p = strstr ((char *)connection->received, "<Response>");
+          if (G_LIKELY (p))
+            cts_len = connection->received_len - (p - connection->received);
+        }
+
+      if (cts_len > -1)
+        {
           /* calculate the header length */
-          n = connection->received->len - strtol (p, NULL, 10);
+          n = connection->received_len - cts_len;
 
           if (G_LIKELY (n > 0))
             {
               /* erase the header from the reveiced string */
-              g_string_erase (connection->received, 0, n);
+              void *tmp = g_malloc(cts_len+1);
+              memcpy(tmp, connection->received+n, cts_len);
+              ((gchar *)tmp)[cts_len] = 0;
+              g_free(connection->received);
+              connection->received = tmp;
+              connection->received_len = cts_len;
             }
 
           /* everything went fine... */
@@ -401,7 +445,7 @@ weather_http_receive_data_destroyed (gpointer user_data)
   if (connection->status == STATUS_SUCCEED && connection->cb_func)
     {
       /* execute the callback process */
-      (*connection->cb_func) (TRUE, g_string_free (connection->received, FALSE),
+      (*connection->cb_func) (TRUE, connection->received, connection->received_len,
                               connection->cb_user_data);
     }
   else if (connection->status == STATUS_RESCHEDULE &&
@@ -410,8 +454,8 @@ weather_http_receive_data_destroyed (gpointer user_data)
       /* cleanup the received data */
       if (connection->received)
         {
-          g_string_free (connection->received, TRUE);
-          connection->received = NULL;
+          g_free(connection->received);
+	  connection->received = NULL;
         }
 
       /* increase counter */
@@ -429,11 +473,13 @@ weather_http_receive_data_destroyed (gpointer user_data)
     {
       /* execute empty callback */
       if (connection->cb_func)
-        (*connection->cb_func) (FALSE, NULL, connection->cb_user_data);
+        (*connection->cb_func) (FALSE, NULL, 0, connection->cb_user_data);
 
       /* cleanup */
-      if (connection->received)
-        g_string_free (connection->received, TRUE);
+      if (connection->received) {
+        g_free(connection->received);
+        connection->received = NULL;
+      }
     }
 
   /* remove from the list */
@@ -445,7 +491,7 @@ weather_http_receive_data_destroyed (gpointer user_data)
   g_free (connection->proxy_host);
 
   /* cleanup */
-  panel_slice_free (WeatherConnection, connection);
+  g_slice_free (WeatherConnection, connection);
 }
 
 
@@ -461,7 +507,7 @@ weather_http_receive_data (const gchar  *hostname,
   WeatherConnection *connection;
 
   /* create slice */
-  connection = panel_slice_new0 (WeatherConnection);
+  connection = g_slice_new0 (WeatherConnection);
 
   /* set connection properties */
   connection->hostname = g_strdup (hostname);
@@ -472,6 +518,7 @@ weather_http_receive_data (const gchar  *hostname,
   connection->cb_user_data = user_data;
   connection->status = STATUS_NOT_EXECUTED;
   connection->received = NULL;
+  connection->received_len = 0;
   connection->fd = -1;
   connection->counter = 1;
 
