@@ -1,6 +1,4 @@
-/*  $Id: weather-http.h 7588 2009-06-16 07:06:04Z colin $
- *
- *  Copyright (c) 2003-2007 Xfce Development Team
+/*  Copyright (c) 2003-2007 Xfce Development Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +20,7 @@
 
 G_BEGIN_DECLS
 
-typedef void   (*WeatherFunc) (gboolean succeed, gchar *received, gpointer user_data);
+typedef void   (*WeatherFunc) (gboolean succeed, gchar *received, size_t len, gpointer user_data);
 
 void weather_http_cleanup_qeue (void);
 
