@@ -1,6 +1,4 @@
-/*  $Id: weather-icon.c 7588 2009-06-16 07:06:04Z colin $
- *
- *  Copyright (c) 2003-2007 Xfce Development Team
+/*  Copyright (c) 2003-2007 Xfce Development Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,6 +21,7 @@
 
 #include <glib.h>
 #include <gtk/gtk.h>
+#include <string.h>
 
 #include "weather-icon.h"
 
@@ -39,6 +38,9 @@ get_icon (const gchar *number,
   GdkPixbuf *image = NULL;
   gchar     *filename;
 
+  if (number == NULL || strcmp (number, "-") == 0)
+    number = "99";
+
   filename = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "%s" G_DIR_SEPARATOR_S "%s.png",
                               THEMESDIR, DEFAULT_W_THEME, number);
 
