@@ -1,6 +1,4 @@
-/*  $Id: weather-search.c 7609 2009-06-18 17:29:09Z colin $
- *
- *  Copyright (c) 2003-2007 Xfce Development Team
+/*  Copyright (c) 2003-2007 Xfce Development Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -75,6 +73,7 @@ sanitize_str (const gchar *str)
 static void
 cb_searchdone (gboolean  succeed,
                gchar    *received,
+	       size_t    len,
                gpointer  user_data)
 {
   search_dialog *dialog = (search_dialog *) user_data;
@@ -139,7 +138,7 @@ cb_searchdone (gboolean  succeed,
       gtk_dialog_set_response_sensitive(GTK_DIALOG(dialog->dialog), GTK_RESPONSE_ACCEPT, TRUE);
     }
   }
-  
+
 gtk_tree_view_column_set_title(dialog->column, _("Results"));
   return;
 }
@@ -166,7 +165,7 @@ search_cb (GtkWidget *widget,
       return;
     }
   }
-  
+
   g_free(dialog->last_search);
   dialog->last_search = g_strdup(str);
 
@@ -212,7 +211,7 @@ create_search_dialog (GtkWindow *parent,
   search_dialog     *dialog;
   GtkWidget         *dialog_vbox, *dialog_action;
 
-  dialog = panel_slice_new0 (search_dialog);
+  dialog = g_slice_new0 (search_dialog);
 
   dialog->proxy_host = proxy_host;
   dialog->proxy_port = proxy_port;
@@ -243,7 +242,7 @@ create_search_dialog (GtkWindow *parent,
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
   gtk_box_pack_start (GTK_BOX (dialog_vbox), vbox,
                       TRUE, TRUE, 0);
-  
+
   xfce_titled_dialog_set_subtitle (XFCE_TITLED_DIALOG (dialog->dialog),
 				   _("Enter a city name or zip code"));
 
@@ -252,7 +251,7 @@ create_search_dialog (GtkWindow *parent,
 
   dialog->search_entry = gtk_entry_new ();
   gtk_box_pack_start (GTK_BOX (hbox), dialog->search_entry, TRUE, TRUE, 0);
-  
+
   g_signal_connect (G_OBJECT (dialog->search_entry), "activate",
                     G_CALLBACK (search_cb), dialog);
 
@@ -328,7 +327,7 @@ free_search_dialog (search_dialog * dialog)
 
   gtk_widget_destroy (dialog->dialog);
 
-  panel_slice_free (search_dialog, dialog);
+  g_slice_free (search_dialog, dialog);
 }
 
 typedef struct {
@@ -336,21 +335,19 @@ typedef struct {
   gint proxy_port;
   void (*cb)(const gchar *loc_name, const gchar *loc_code, gpointer user_data);
   gpointer user_data;
-} 
+}
 geolocation_data;
 
 static void
 cb_geo_searchdone (gboolean  succeed,
                gchar    *received,
+	       size_t    len,
                gpointer  user_data)
 {
   geolocation_data *data = (geolocation_data *) user_data;
   xmlDoc        *doc;
   xmlNode       *cur_node;
   gchar         *id, *city;
-  gboolean      found = FALSE;
-  GtkTreeIter       iter;
-  GtkTreeSelection *selection;
 
   if (!succeed || received == NULL) {
     data->cb(NULL, NULL, data->user_data);
@@ -400,7 +397,7 @@ cb_geo_searchdone (gboolean  succeed,
             }
         }
     }
-  
+
   g_free(data);
   xmlFreeDoc (doc);
 }
@@ -408,6 +405,7 @@ cb_geo_searchdone (gboolean  succeed,
 static void
 cb_geolocation (gboolean  succeed,
                 gchar    *received,
+		size_t    len,
                 gpointer  user_data)
 {
   geolocation_data *data = (geolocation_data *) user_data;
@@ -415,18 +413,28 @@ cb_geolocation (gboolean  succeed,
   xmlNode       *cur_node;
   gchar         *city = NULL, *country = NULL;
   gchar         *country_code = NULL, *region = NULL;
-  gboolean      found = FALSE;
+  gchar         *full_loc;
+  gsize          length;
+  gchar         *p;
 
   if (!succeed || received == NULL) {
     data->cb(NULL, NULL, data->user_data);
     g_free(data);
     return;
   }
+
+  /* hack for archive.xfce.org, which return no content-length */
+  p = strstr (received, "</Response>");
+  if (p != NULL)
+    length = p - received + strlen ("</Response>");
+  else
+    length = strlen (received);
+
   if (g_utf8_validate(received, -1, NULL)) {
     /* force parsing as UTF-8, the XML encoding header may lie */
-    doc = xmlReadMemory (received, strlen (received), NULL, "UTF-8", 0);
+    doc = xmlReadMemory (received, length, NULL, "UTF-8", 0);
   } else {
-    doc = xmlParseMemory (received, strlen(received));
+    doc = xmlParseMemory (received, length);
   }
   g_free (received);
 
@@ -460,30 +468,41 @@ cb_geolocation (gboolean  succeed,
             }
         }
     }
-  
-  if (country_code && region && !strcmp(country_code, "US")) {
-    g_free(country);
-    country = region;
-    region = NULL;
-  }
-  g_free(country_code);
-  g_free(region);
-  
+
+  if (country && city)
+    {
+      if (country_code && !strcmp (country_code, "US") && region)
+        full_loc = g_strdup_printf ("%s, %s", city, region);
+      else
+        full_loc = g_strdup_printf ("%s, %s", city, country);
+    }
+  else if (country)
+    {
+      full_loc = g_strdup (country);
+    }
+  else
+    {
+      full_loc = NULL;
+    }
+
+  g_free (country_code);
+  g_free (region);
+  g_free (country);
+  g_free (city);
+
   xmlFreeDoc (doc);
 
-  if (city && country) {
-     gchar *full_loc = g_strdup_printf("%s, %s", city, country);
+  if (full_loc) {
      gchar *url, *sane_str;
-     g_free(city);
-     g_free(country);
-     
+
      if ((sane_str = sanitize_str (full_loc)) == NULL) {
        data->cb(NULL, NULL, data->user_data);
        g_free(data);
+       g_free(full_loc);
        return;
      }
      g_free(full_loc);
-     
+
      url = g_strdup_printf ("/search/search?where=%s", sane_str);
      g_free (sane_str);
 
@@ -496,15 +515,13 @@ cb_geolocation (gboolean  succeed,
 
 
 
-gboolean weather_search_by_ip(
+void weather_search_by_ip(
 	const gchar *proxy_host, gint proxy_port,
         void (*gui_cb)(const gchar *loc_name, const gchar *loc_code, gpointer user_data),
 	gpointer user_data)
 {
-  gchar *city = NULL, *country = NULL;
-  gchar *search = NULL;
   geolocation_data *data;
-  
+
   if (!gui_cb)
     return;
 
@@ -514,8 +531,10 @@ gboolean weather_search_by_ip(
   data->proxy_host = proxy_host;
   data->proxy_port = proxy_port;
 
-  weather_http_receive_data ("ipinfodb.com", "/ip_query.php",
+  /* archive.xfce.org is our download server that runs mod_geoip
+   * with the www.maxmind.com database */
+  weather_http_receive_data ("archive.xfce.org", "/geolocation",
                              proxy_host, proxy_port,
                              cb_geolocation, data);
-
+  return;
 }
