@@ -1,6 +1,4 @@
-/*  $Id: weather-search.h 7588 2009-06-16 07:06:04Z colin $
- *
- *  Copyright (c) 2003-2007 Xfce Development Team
+/*  Copyright (c) 2003-2007 Xfce Development Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,12 +29,17 @@ typedef struct
   GtkWidget    *dialog;
   GtkWidget    *search_entry;
   GtkWidget    *result_list;
+  GtkWidget    *find_button;
   GtkListStore *result_mdl;
+  GtkTreeViewColumn *column;
 
   gchar        *result;
+  gchar        *result_name;
 
   gchar        *proxy_host;
   gint          proxy_port;
+  
+  gchar        *last_search;
 }
 search_dialog;
 
@@ -44,6 +47,10 @@ search_dialog *create_search_dialog (GtkWindow *, gchar *, gint);
 
 gboolean run_search_dialog (search_dialog * dialog);
 
+void weather_search_by_ip(const gchar *proxy_host, gint proxy_port,
+	void (*gui_cb)(const gchar *loc_name, const gchar *loc_code, gpointer user_data),
+	gpointer user_data);
+
 void free_search_dialog (search_dialog * dialog);
 
 G_END_DECLS
