@@ -1,6 +1,4 @@
-/*  $Id: weather.c 7748 2009-07-19 20:57:42Z colin $
- *
- *  Copyright (c) 2003-2007 Xfce Development Team
+/*   Copyright (c) 2003-2007 Xfce Development Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -245,8 +243,6 @@ set_icon_error (xfceweather_data *data)
   gtk_scrollbox_set_label (GTK_SCROLLBOX (data->scrollbox), -1, str);
   g_free (str);
 
-  gtk_scrollbox_enablecb  (GTK_SCROLLBOX (data->scrollbox), TRUE);
-
   gtk_widget_get_size_request (data->scrollbox, NULL, &height);
 
   if (data->orientation == GTK_ORIENTATION_VERTICAL)
@@ -287,8 +283,6 @@ set_icon_current (xfceweather_data *data)
       g_free (str);
     }
 
-  gtk_scrollbox_enablecb (GTK_SCROLLBOX (data->scrollbox), TRUE);
-
   if (i == 0)
     {
       size = data->size;
@@ -301,9 +295,9 @@ set_icon_current (xfceweather_data *data)
       else
         size = data->size;
     }
-
+ 
   icon = get_icon (get_data (data->weatherdata, WICON), size);
-
+ 
   gtk_image_set_from_pixbuf (GTK_IMAGE (data->iconimage), icon);
 
   if (G_LIKELY (icon))
@@ -321,6 +315,7 @@ set_icon_current (xfceweather_data *data)
 static void
 cb_update (gboolean  succeed,
            gchar    *result,
+	   size_t    len,
            gpointer  user_data)
 {
   xfceweather_data *data = user_data;
@@ -505,7 +500,7 @@ xfceweather_read_config (XfcePanelPlugin  *plugin,
       data->proxy_port = data->saved_proxy_port;
     }
 
-  data->animation_transitions = xfce_rc_read_bool_entry (rc, 
+  data->animation_transitions = xfce_rc_read_bool_entry (rc,
   		"animation_transitions", TRUE);
 
   gtk_scrollbox_set_animate(GTK_SCROLLBOX(data->scrollbox), data->animation_transitions);
@@ -627,8 +622,7 @@ forecast_click (GtkWidget *widget,
     }
   else
     {
-      data->summary_window = create_summary_window (data->weatherdata,
-                                                    data->unit);
+      data->summary_window = create_summary_window (data);
       g_signal_connect (G_OBJECT (data->summary_window), "destroy",
                 	G_CALLBACK (close_summary), data);
 
@@ -704,7 +698,7 @@ xfceweather_dialog_response (GtkWidget          *dlg,
 
       gtk_widget_destroy (dlg);
       gtk_list_store_clear (dialog->mdl_xmloption);
-      panel_slice_free (xfceweather_dialog, dialog);
+      g_slice_free (xfceweather_dialog, dialog);
 
       xfce_panel_plugin_unblock_menu (data->plugin);
       xfceweather_write_config (data->plugin, data);
@@ -757,17 +751,17 @@ static gboolean weather_get_tooltip_cb (GtkWidget        *widget,
 					gint              y,
 					gboolean          keyboard_mode,
 					GtkTooltip       *tooltip,
-					xfceweather_data *data) 
+					xfceweather_data *data)
 {
   GdkPixbuf *icon;
   gchar *markup_text;
-  
+
   if (data->weatherdata == NULL) {
     gtk_tooltip_set_text (tooltip, _("Cannot update weather data"));
   } else {
     markup_text = g_markup_printf_escaped(
   	  "<b>%s</b>\n"
-	  "%s", 
+	  "%s",
 	  get_data (data->weatherdata, DNAM),
 	  translate_desc (get_data (data->weatherdata, TRANS))
 	  );
@@ -777,7 +771,7 @@ static gboolean weather_get_tooltip_cb (GtkWidget        *widget,
   icon = get_icon (get_data (data->weatherdata, WICON), 32);
   gtk_tooltip_set_icon (tooltip, icon);
   g_object_unref (G_OBJECT(icon));
-  
+
   return TRUE;
 }
 
@@ -785,8 +779,8 @@ static gboolean weather_get_tooltip_cb (GtkWidget        *widget,
 static xfceweather_data *
 xfceweather_create_control (XfcePanelPlugin *plugin)
 {
-  xfceweather_data *data = panel_slice_new0 (xfceweather_data);
-  GtkWidget        *refresh, *forecast;
+  xfceweather_data *data = g_slice_new0 (xfceweather_data);
+  GtkWidget        *refresh, *mi;
   datas             lbl;
   GdkPixbuf        *icon = NULL;
 
@@ -819,12 +813,12 @@ xfceweather_create_control (XfcePanelPlugin *plugin)
 
   data->tooltipbox = gtk_event_box_new ();
   gtk_container_add (GTK_CONTAINER (data->tooltipbox), data->top_vbox);
+  gtk_event_box_set_visible_window (GTK_EVENT_BOX (data->tooltipbox), FALSE);
   gtk_widget_show_all (data->tooltipbox);
-  GTK_WIDGET_SET_FLAGS (GTK_WIDGET(data->tooltipbox), GTK_NO_WINDOW);
 
 #if GTK_CHECK_VERSION(2,12,0)
   g_object_set (G_OBJECT(data->tooltipbox), "has-tooltip", TRUE, NULL);
-  g_signal_connect(G_OBJECT(data->tooltipbox), "query-tooltip", 
+  g_signal_connect(G_OBJECT(data->tooltipbox), "query-tooltip",
 		   G_CALLBACK(weather_get_tooltip_cb),
 		  data);
 #endif
@@ -846,18 +840,18 @@ xfceweather_create_control (XfcePanelPlugin *plugin)
   xfce_panel_plugin_menu_insert_item (plugin, GTK_MENU_ITEM (refresh));
 
   /* add refresh button to right click menu, for people who missed the middle mouse click feature */
-  forecast = gtk_image_menu_item_new_with_mnemonic (_("_Forecast"));
+  mi = gtk_image_menu_item_new_with_mnemonic (_("_Forecast"));
   icon = get_icon ("32", 16);
-  gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(forecast),
+  gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(mi),
   	gtk_image_new_from_pixbuf(icon));
   if (G_LIKELY (icon))
     g_object_unref (G_OBJECT (icon));
-  gtk_widget_show (forecast);
+  gtk_widget_show (mi);
 
-  g_signal_connect (G_OBJECT (forecast), "activate",
+  g_signal_connect (G_OBJECT (mi), "activate",
                     G_CALLBACK (forecast_click), data);
 
-  xfce_panel_plugin_menu_insert_item (plugin, GTK_MENU_ITEM (forecast));
+  xfce_panel_plugin_menu_insert_item (plugin, GTK_MENU_ITEM (mi));
 
   /* assign to tempval because g_array_append_val () is using & operator */
   lbl = TEMP;
@@ -895,7 +889,6 @@ xfceweather_free (XfcePanelPlugin  *plugin,
       data->updatetimeout = 0;
     }
 
-  free_get_data_buffer ();
   xmlCleanupParser ();
 
   /* Free Tooltip */
@@ -912,7 +905,7 @@ xfceweather_free (XfcePanelPlugin  *plugin,
   /* Free Array */
   g_array_free (data->labels, TRUE);
 
-  panel_slice_free (xfceweather_data, data);
+  g_slice_free (xfceweather_data, data);
 }
 
 
@@ -955,7 +948,7 @@ xfceweather_set_orientation (XfcePanelPlugin  *panel,
   g_object_unref(G_OBJECT(data->vbox_center_scrollbox));
 
   gtk_scrollbox_clear (GTK_SCROLLBOX (data->scrollbox));
-  
+
   if (data->weatherdata)
     set_icon_current (data);
   else
